[llvm-commits] CVS: llvm/include/llvm/Analysis/ScalarEvolution.h
Dan Gohman
djg at cray.com
Tue Jun 19 07:28:58 PDT 2007
Changes in directory llvm/include/llvm/Analysis:
ScalarEvolution.h updated: 1.21 -> 1.22
---
Log message:
Rename ScalarEvolution::deleteInstructionFromRecords to
deleteValueFromRecords and loosen the types to all it to accept
Value* instead of just Instruction*, since this is what
ScalarEvolution uses internally anyway. This allows more flexibility
for future uses.
---
Diffs of the changes: (+3 -3)
ScalarEvolution.h | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
Index: llvm/include/llvm/Analysis/ScalarEvolution.h
diff -u llvm/include/llvm/Analysis/ScalarEvolution.h:1.21 llvm/include/llvm/Analysis/ScalarEvolution.h:1.22
--- llvm/include/llvm/Analysis/ScalarEvolution.h:1.21 Sun May 6 08:37:15 2007
+++ llvm/include/llvm/Analysis/ScalarEvolution.h Tue Jun 19 09:28:30 2007
@@ -232,10 +232,10 @@
/// an analyzable loop-invariant iteration count.
bool hasLoopInvariantIterationCount(const Loop *L) const;
/// deleteInstructionFromRecords - This method should be called by the
/// client before it removes an instruction from the program, to make sure
/// that no dangling references are left around.
- void deleteInstructionFromRecords(Instruction *I) const;
+ void deleteValueFromRecords(Value *V) const;
virtual bool runOnFunction(Function &F);
virtual void releaseMemory();
More information about the llvm-commits
@@ -232,10 +232,10 @@
/// an analyzable loop-invariant iteration count.
bool hasLoopInvariantIterationCount(const Loop *L) const;
- /// deleteInstructionFromRecords - This method should be called by the
- /// client before it removes an instruction from the program, to make sure
+ /// deleteValueFromRecords - This method should be called by the
+ /// client before it removes a Value from the program, to make sure
/// that no dangling references are left around.
mailing list